==> Paws-0.33.tar.gz: Paws-0.33/lib/Paws/OpsWorks/StackConfigurationManager.pm <==
package Paws::OpsWorks::StackConfigurationManager;
  use Moose;
  has Name => (is => 'ro', isa => 'Str');
  has Version => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::StackConfigurationManager

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::OpsWorks::StackConfigurationManager object:

  $service_obj->Method(Att1 => { Name => $value, ..., Version => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::OpsWorks::StackConfigurationManager object:

  $result = $service_obj->Method(...);
  $result->Att1->Name

=head1 DESCRIPTION

Describes the configuration manager.

=head1 ATTRIBUTES


=head2 Name => Str

  The name. This parameter must be set to "Chef".


=head2 Version => Str

  The Chef version. This parameter must be set to 12, 11.10, or 11.4 for
Linux stacks, and to 12.2 for Windows stacks. The default value for
Linux stacks is 11.4.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::OpsWorks>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/OpsWorks/StackConfigurationManager.pm <==
package Paws::OpsWorks::StackConfigurationManager;
  use Moose;
  has Name => (is => 'ro', isa => 'Str');
  has Version => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::OpsWorks::StackConfigurationManager

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::OpsWorks::StackConfigurationManager object:

  $service_obj->Method(Att1 => { Name => $value, ..., Version => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::OpsWorks::StackConfigurationManager object:

  $result = $service_obj->Method(...);
  $result->Att1->Name

=head1 DESCRIPTION

Describes the configuration manager.

=head1 ATTRIBUTES


=head2 Name => Str

  The name. This parameter must be set to "Chef".


=head2 Version => Str

  The Chef version. This parameter must be set to 12, 11.10, or 11.4 for
Linux stacks, and to 12.2 for Windows stacks. The default value for
Linux stacks is 11.4.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::OpsWorks>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
